#[doc(hidden)]pub struct Custom { /* private fields */ }🔬This is a nightly-only experimental API. (
core_io_internals)Implementations
Sourceimpl Custom
impl Custom
Sourcepub unsafe fn from_raw(
kind: ErrorKind,
error: NonNull<dyn Error + Send + Sync>,
error_drop: unsafe fn(*mut dyn Error + Send + Sync),
outer_drop: unsafe fn(*mut Custom),
) -> Custom
🔬This is a nightly-only experimental API. (core_io_internals)
pub unsafe fn from_raw( kind: ErrorKind, error: NonNull<dyn Error + Send + Sync>, error_drop: unsafe fn(*mut dyn Error + Send + Sync), outer_drop: unsafe fn(*mut Custom), ) -> Custom
core_io_internals)Safety
errormust be valid for up to a static lifetime, and own its pointee.error_dropmust be safe to call for the pointererrorexactly once.outer_dropmust be safe to call on a pointer to this instance ofCustomif it were stored within aCustomOwner.
pub fn into_raw(self) -> NonNull<dyn Error + Send + Sync>
🔬This is a nightly-only experimental API. (
core_io_internals)